@@ -77,18 +77,18 @@ typedef unsigned __int32 uint32_t;  /* 32 bit unsigned */
 #include <stdint.h>
 #endif // _MSC_VER
 
-#ifndef WT_CXX11
-
-#if defined(__GXX_EXPERIMENTAL_CXX0X__) || __cplusplus >= 201103L || _MSC_VER >= 1900
-#define WT_CXX11
-#endif
-
-#ifdef WT_CXX11
-#define WT_CXX11ONLY(x) x
+#ifdef wt_EXPORTS
+  #define DATE_BUILD_DLL
 #else
-#define WT_CXX11ONLY(x)
+  #ifdef WT_STATIC
+    #define DATE_BUILD_LIB
+  #endif
 #endif
 
+#ifdef WT_WIN32
+#define USE_OS_TZDB 0
+#else
+#define USE_OS_TZDB 1
 #endif
 
 #endif // DLLDEFS_H_
